==> qmmp-0.9.2-1.00.tar.gz: qmmp-1.0.0/src/plugins/Visual/analyzer/translations/analyzer_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="47"/>
        <source>Qmmp Analyzer</source>
        <translation>Qmmp 可视化分析器</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="364"/>
        <source>Peaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="367"/>
        <source>Refresh Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="370"/>
        <source>50 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="371"/>
        <source>25 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="372"/>
        <source>10 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="373"/>
        <source>5 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="380"/>
        <source>Analyzer Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="383"/>
        <location filename="../analyzer.cpp" line="397"/>
        <source>Slowest</source>
        <translation type="unfinished">最慢</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="384"/>
        <location filename="../analyzer.cpp" line="398"/>
        <source>Slow</source>
        <translation type="unfinished">慢</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="385"/>
        <location filename="../analyzer.cpp" line="399"/>
        <source>Medium</source>
        <translation type="unfinished">中</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="386"/>
        <location filename="../analyzer.cpp" line="400"/>
        <source>Fast</source>
        <translation type="unfinished">快</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="387"/>
        <location filename="../analyzer.cpp" line="401"/>
        <source>Fastest</source>
        <translation type="unfinished">最快</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="394"/>
        <source>Peaks Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="408"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="408"/>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>可视化分析器插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation>颜色</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation>峰值：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation>分析 #1：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation>背景：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation>分析 #2：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation>分析 #3：</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="31"/>
        <source>Analyzer Plugin</source>
        <translation>可视化分析器插件</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>关于可视化分析器插件</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Qmmp 可视化分析器插件</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Visual/analyzer/translations/analyzer_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="47"/>
        <source>Qmmp Analyzer</source>
        <translation>Qmmp 可视化分析器</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="356"/>
        <source>Peaks</source>
        <translation>峰</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="359"/>
        <source>Refresh Rate</source>
        <translation>刷新率</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="362"/>
        <source>50 fps</source>
        <translation>50 fps</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="363"/>
        <source>25 fps</source>
        <translation>25 帧每秒</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="364"/>
        <source>10 fps</source>
        <translation>10 帧每秒</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="365"/>
        <source>5 fps</source>
        <translation>5 帧每秒</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="372"/>
        <source>Analyzer Falloff</source>
        <translation>分析器坠落</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="375"/>
        <location filename="../analyzer.cpp" line="389"/>
        <source>Slowest</source>
        <translation>最慢</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="376"/>
        <location filename="../analyzer.cpp" line="390"/>
        <source>Slow</source>
        <translation>慢</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="377"/>
        <location filename="../analyzer.cpp" line="391"/>
        <source>Medium</source>
        <translation>中等</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="378"/>
        <location filename="../analyzer.cpp" line="392"/>
        <source>Fast</source>
        <translation>快</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="379"/>
        <location filename="../analyzer.cpp" line="393"/>
        <source>Fastest</source>
        <translation>最快</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="386"/>
        <source>Peaks Falloff</source>
        <translation>顶峰坠落</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="400"/>
        <source>&amp;Full Screen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="400"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation>选择颜色</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation>可视化分析器插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation>单块儿尺寸</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation>颜色</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation>峰值：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation>分析 #1：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation>背景：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation>分析 #2：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation>分析 #3：</translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="32"/>
        <source>Analyzer Plugin</source>
        <translation>可视化分析器插件</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>About Analyzer Visual Plugin</source>
        <translation>关于可视化分析器插件</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="52"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation>Qmmp 可视化分析器插件</translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
